package cn.com.infosec.asn1.cryptopro;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class GOST3410PublicKeyAlgParameters extends ASN1Encodable {
   private DERObjectIdentifier publicKeyParamSet;
   private DERObjectIdentifier digestParamSet;
   private DERObjectIdentifier encryptionParamSet;

   public static GOST3410PublicKeyAlgParameters getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static GOST3410PublicKeyAlgParameters getInstance(Object obj) {
      if (obj != null && !(obj instanceof GOST3410PublicKeyAlgParameters)) {
         if (obj instanceof ASN1Sequence) {
            return new GOST3410PublicKeyAlgParameters((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid GOST3410Parameter: " + obj.getClass().getName());
         }
      } else {
         return (GOST3410PublicKeyAlgParameters)obj;
      }
   }

   public GOST3410PublicKeyAlgParameters(DERObjectIdentifier publicKeyParamSet, DERObjectIdentifier digestParamSet) {
      this.publicKeyParamSet = publicKeyParamSet;
      this.digestParamSet = digestParamSet;
      this.encryptionParamSet = null;
   }

   public GOST3410PublicKeyAlgParameters(DERObjectIdentifier publicKeyParamSet, DERObjectIdentifier digestParamSet, DERObjectIdentifier encryptionParamSet) {
      this.publicKeyParamSet = publicKeyParamSet;
      this.digestParamSet = digestParamSet;
      this.encryptionParamSet = encryptionParamSet;
   }

   public GOST3410PublicKeyAlgParameters(ASN1Sequence seq) {
      this.publicKeyParamSet = (DERObjectIdentifier)seq.getObjectAt(0);
      this.digestParamSet = (DERObjectIdentifier)seq.getObjectAt(1);
      if (seq.size() > 2) {
         this.encryptionParamSet = (DERObjectIdentifier)seq.getObjectAt(2);
      }

   }

   public DERObjectIdentifier getPublicKeyParamSet() {
      return this.publicKeyParamSet;
   }

   public DERObjectIdentifier getDigestParamSet() {
      return this.digestParamSet;
   }

   public DERObjectIdentifier getEncryptionParamSet() {
      return this.encryptionParamSet;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.publicKeyParamSet);
      var10001.add(this.digestParamSet);
      DERObjectIdentifier var2;
      if ((var2 = this.encryptionParamSet) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
